summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp b/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
index 3f8ff7bf..af0785de 100644
--- a/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
+++ b/kopete/protocols/groupwise/libgroupwise/tasks/updatefoldertask.cpp
@@ -21,7 +21,7 @@
#include "updatefoldertask.h"
-UpdateFolderTask::UpdateFolderTask(Task* parent): UpdateItemTask(parent)
+UpdateFolderTask::UpdateFolderTask(Task* tqparent): UpdateItemTask(tqparent)
{
}
@@ -39,7 +39,7 @@ void UpdateFolderTask::renameFolder( const TQString & newName, const GroupWise::
renamed.name = newName;
// add the new version of the folder, marked add
lst.append( new Field::MultiField( NM_A_FA_FOLDER, NMFIELD_METHOD_ADD, 0, NMFIELD_TYPE_ARRAY, folderToFields( renamed ) ) );
// let our parent class package it up as a contactlist in a transfer
UpdateItemTask::item( lst );
}
@@ -39,7 +39,7 @@ void UpdateFolderTask::renameFolder( const TQString & newName, const GroupWise::
// add the new version of the folder, marked add
lst.append( new Field::MultiField( NM_A_FA_FOLDER, NMFIELD_METHOD_ADD, 0, NMFIELD_TYPE_ARRAY, folderToFields( renamed ) ) );
- // let our parent class package it up as a contactlist in a transfer
+ // let our tqparent class package it up as a contactlist in a transfer
UpdateItemTask::item( lst );
}